@@ -18,46 +18,42 @@ test_that("systematic tests", {
     POSIXct  = as.POSIXct("2000-01-01") + 0:30
   )
   brk_funs <- list(
-    brk_evenly      = brk_evenly(2),
-    brk_proportions = brk_proportions(c(0.25, 0.6)),
-    brk_manual      = brk_manual(1:3, rep(TRUE, 3)),
-    brk_manual2     = brk_manual(1:3, c(FALSE, TRUE, FALSE)),
-    brk_mean_sd     = brk_mean_sd(),
-    brk_mean_sd2    = brk_mean_sd(c(1, 1.96)),
-    brk_pretty      = brk_pretty(),
-    brk_n           = brk_n(5),
-    brk_quantiles   = brk_quantiles(1:3/4),
-    brk_default     = brk_default(1:3),
-    brk_default2    = brk_default(c(1, 2, 2, 3)),
-    brk_default_lo  = brk_default(1),
-    brk_default_hi  = brk_default(5),
-    brk_width       = brk_width(1),
-    brk_width2      = brk_width(1, 0),
-    brk_w_difft_day = brk_width(as.difftime(5, units = "days")),
-    brk_w_difft_sec = brk_width(as.difftime(5, units = "secs")),
-    brk_def_Date    = brk_default(as.Date("1950-01-05") + c(0, 5)),
-    brk_def_POSIXct = brk_default(as.POSIXct("2000-01-01") + c(10, 20))
+    brk_evenly      = expression(brk_evenly(2)),
+    brk_proportions = expression(brk_proportions(c(0.25, 0.6))),
+    brk_manual      = expression(brk_manual(1:3, c(FALSE, TRUE, FALSE))),
+    brk_mean_sd     = expression(brk_mean_sd()),
+    brk_pretty      = expression(brk_pretty()),
+    brk_n           = expression(brk_n(5)),
+    brk_quantiles   = expression(brk_quantiles(1:3/4)),
+    brk_default     = expression(brk_default(1:3)),
+    brk_default2    = expression(brk_default(c(1, 2, 2, 3))),
+    brk_default_lo  = expression(brk_default(1)),
+    brk_default_hi  = expression(brk_default(5)),
+    brk_width       = expression(brk_width(1)),
+    brk_width2      = expression(brk_width(1, 0)),
+    brk_w_difft_day = expression(brk_width(as.difftime(5, units = "days"))),
+    brk_w_difft_sec = expression(brk_width(as.difftime(5, units = "secs"))),
+    brk_def_Date    = expression(brk_default(as.Date("1950-01-05") + c(0, 5))),
+    brk_def_POSIXct = expression(brk_default(as.POSIXct("2000-01-01") + c(10, 20)))
   )
   lbl_funs <- list(
-    lbl_dash          = lbl_dash(),
-    lbl_dash2         = lbl_dash("/"),
-    lbl_intervals     = lbl_intervals(),
-    lbl_intervals_raw = lbl_intervals(raw = TRUE),
-    lbl_seq           = lbl_seq("a"),
-    lbl_seq2          = lbl_seq("(i)"),
-    lbl_manual        = lbl_manual(letters[1:2]),
-    lbl_manual2       = lbl_manual(letters[1:2], "%s)"),
-    lbl_endpoints     = lbl_endpoints(),
-    lbl_midpoints     = lbl_midpoints()
+    lbl_dash          = expression(lbl_dash()),
+    lbl_intervals     = expression(lbl_intervals()),
+    lbl_seq           = expression(lbl_seq("a")),
+    lbl_endpoints     = expression(lbl_endpoints()),
+    lbl_midpoints     = expression(lbl_midpoints())
   )
 
   test_df <- expand.grid(
     x         = x_vals,
     brk_fun   = names(brk_funs),
     lbl_fun   = names(lbl_funs),
-    extend    = c(TRUE, FALSE),
+    # we translate NA to NULL in chop(); doing this means we don't need a list():
+    extend    = c(TRUE, FALSE, NA),
     left      = c(TRUE, FALSE),
     close_end = c(TRUE, FALSE),
+    # ditto:
+    raw       = c(TRUE, FALSE, NA),
     drop      = c(TRUE, FALSE),
     stringsAsFactors = FALSE
   )
@@ -70,9 +66,7 @@ test_that("systematic tests", {
   }
 
   skip_test(! left & brk_fun == "brk_manual")
-  skip_test(! left & brk_fun == "brk_manual2")
   skip_test(close_end & brk_fun == "brk_manual")
-  skip_test(close_end & brk_fun == "brk_manual2")
 
   POSIXct_breaks <- c("brk_def_POSIXct", "brk_w_difft_sec")
   Date_breaks <- c("brk_def_Date", "brk_w_difft_day")
@@ -84,6 +78,8 @@ test_that("systematic tests", {
   skip_test(names(x) != "POSIXct" & brk_fun == "brk_w_difft_sec")
 
   test_df$expect <- "succeed"
+  test_df$row <- seq_len(nrow(test_df))
+
   # some things should fail
   should_fail <-   function (cond) test_df$expect[cond] <<- "error"
   should_warn <-   function (cond) test_df$expect[cond] <<- "warn"
@@ -112,6 +108,46 @@ test_that("systematic tests", {
           extend == FALSE
         ))
 
+  # ditto when extend is NULL and there's no non-NA data
+  # here we have to fail even though with some data we'd be OK
+  should_fail(with(test_df,
+                    brk_fun %in% c("brk_default_hi", "brk_default_lo") &
+                    names(x) %in% c("all_NAs", "none") &
+                    is.na(extend)
+  ))
+
+  # raw endpoints get duplicated if multiple quantiles are infinite:
+  dont_care(with(test_df,
+                   names(x) %in% c("inf_lo", "inf_hi") &
+                   brk_fun == "brk_quantiles" &
+                   lbl_fun == "lbl_midpoints" &
+                   raw == TRUE &
+                   extend == TRUE &
+                   close_end == FALSE
+                 ))
+  dont_care(with(test_df,
+                   names(x) == "inf_lo" &
+                   brk_fun == "brk_quantiles" &
+                   lbl_fun == "lbl_endpoints" &
+                   raw == TRUE &
+                   extend == TRUE &
+                   left == FALSE &
+                   close_end == FALSE
+                 ))
+
+  # lbl_endpoints() can create duplicates
+  # when you extend an open interval to add a singleton
+  # e.g. {1}, (1, 2]
+  dont_care(with(test_df,
+                   lbl_fun == "lbl_endpoints" &
+                   left == FALSE & is.na(extend)
+                 ))
+  dont_care(with(test_df,
+                   lbl_fun == "lbl_endpoints" &
+                   brk_fun %in% c("brk_default_lo", "brk_manual") &
+                   left == TRUE & is.na(extend)
+                 ))
+
   # brk_default2 has breaks 1,2,2,3
   # with lbl_endpoints, this may create duplicate left endpoints
   # ie the user asked for something we can't do
@@ -140,15 +176,33 @@ test_that("systematic tests", {
 
   should_either(names(test_df$x) == "complex")
 
-  for (r in seq_len(nrow(test_df))) {
+  # we sample the same 10000 rows every day
+  seed <- as.numeric(Sys.Date())
+  set.seed(seed)
+  test_everything <- isTRUE(as.logical(Sys.getenv("CI"))) ||
+                              getOption("santoku.test_everything", FALSE)
+
+  sample_rows <- if (test_everything) {
+                   seq_len(nrow(test_df))
+                 } else {
+                   sort(sample(nrow(test_df), 10000, replace = FALSE))
+                 }
+
+  for (r in sample_rows) {
     tdata <- test_df[r, ]
     if (is.na(tdata$expect)) next
+    if (is.na(tdata$extend)) tdata$extend <- NULL
+    if (is.na(tdata$raw)) tdata$raw <- NULL
 
     x <- tdata$x[[1]]
+    format_null <- function (x) if (is.null(x)) "NULL" else x
     info <- sprintf(
-          "row: %s x: %s breaks: %s labels: %s extend: %s left: %s close_end: %s drop: %s",
-          r, names(tdata$x), tdata$brk_fun, tdata$lbl_fun, tdata$extend,
-          tdata$left, tdata$close_end, tdata$drop)
+          "seed: %s row: %s
+          command: chop(%s, %s, labels = %s, extend = %s, left = %s,
+                     close_end = %s, raw = %s, drop = %s)",
+          seed, tdata$row, tdata$x, as.character(brk_funs[[tdata$brk_fun]]),
+          as.character(lbl_funs[[tdata$lbl_fun]]), format_null(tdata$extend),
+          tdata$left, tdata$close_end, format_null(tdata$raw), tdata$drop)
 
     # NA means "no error":
     regexp <- switch(tdata$expect, "succeed" = NA, NULL)
@@ -157,17 +211,18 @@ test_that("systematic tests", {
     # suppressWarnings or we drown in them:
     suppressWarnings(exp_fn(
             chop(x,
-              breaks    = brk_funs[[tdata$brk_fun]],
-              labels    = lbl_funs[[tdata$lbl_fun]],
+              breaks    = eval(brk_funs[[tdata$brk_fun]]),
+              labels    = eval(lbl_funs[[tdata$lbl_fun]]),
               extend    = tdata$extend,
               left      = tdata$left,
               close_end = tdata$close_end,
+              raw       = tdata$raw,
               drop      = tdata$drop
             ),
             regexp = regexp,
             class  = err_class,
             info   = info
           ))
-
   }
 })
+
